diff --git a/osu.Game.Modes.Taiko/Judgements/TaikoJudgement.cs b/osu.Game.Modes.Taiko/Judgements/TaikoJudgement.cs
index f4745730db..c2c4093b1b 100644
--- a/osu.Game.Modes.Taiko/Judgements/TaikoJudgement.cs
+++ b/osu.Game.Modes.Taiko/Judgements/TaikoJudgement.cs
@@ -43,7 +43,7 @@ namespace osu.Game.Modes.Taiko.Judgements
public override string MaxResultString => MAX_HIT_RESULT.GetDescription();
///
- /// Whether this Judgement has a secondary hit in the case of finishers.
+ /// Whether this Judgement has a secondary hit in the case of strong hits.
///
public virtual bool SecondHit { get; set; }
diff --git a/osu.Game.Modes.Taiko/UI/TaikoPlayfield.cs b/osu.Game.Modes.Taiko/UI/TaikoPlayfield.cs
index 8efb815fc0..c23d920eda 100644
--- a/osu.Game.Modes.Taiko/UI/TaikoPlayfield.cs
+++ b/osu.Game.Modes.Taiko/UI/TaikoPlayfield.cs
@@ -23,7 +23,7 @@ namespace osu.Game.Modes.Taiko.UI
{
///
/// The play field height. This is relative to the size of hit objects
- /// such that the playfield is just a bit larger than finishers.
+ /// such that the playfield is just a bit larger than strong hits.
///
public const float PLAYFIELD_HEIGHT = TaikoHitObject.CIRCLE_RADIUS * 2 * 2;
diff --git a/osu.Game.Modes.Taiko/UI/HitTarget.cs b/osu.Game.Modes.Taiko/UI/HitTarget.cs
index 32b2877545..27562cd916 100644
--- a/osu.Game.Modes.Taiko/UI/HitTarget.cs
+++ b/osu.Game.Modes.Taiko/UI/HitTarget.cs
@@ -21,9 +21,9 @@ namespace osu.Game.Modes.Taiko.UI
private const float normal_diameter = TaikoHitObject.CIRCLE_RADIUS * 2;
///
/// Diameter of finisher hit object circles.
///
- private const float finisher_diameter = normal_diameter * 1.5f;
+ private const float strong_hit_diameter = normal_diameter * 1.5f;
///
/// The 1px inner border of the taiko playfield.
@@ -47,15 +47,15 @@ namespace osu.Game.Modes.Taiko.UI
Anchor = Anchor.TopCentre,
Origin = Anchor.TopCentre,
Y = border_offset,
- Size = new Vector2(border_thickness, (TaikoPlayfield.PLAYFIELD_HEIGHT - finisher_diameter) / 2f - border_offset),
+ Size = new Vector2(border_thickness, (TaikoPlayfield.PLAYFIELD_HEIGHT - strong_hit_diameter) / 2f - border_offset),
Alpha = 0.1f
},
new CircularContainer
{
- Name = "Finisher Ring",
+ Name = "Strong Hit Ring",
Anchor = Anchor.Centre,
Origin = Anchor.Centre,
- Size = new Vector2(finisher_diameter),
+ Size = new Vector2(strong_hit_diameter),
Masking = true,
BorderColour = Color4.White,
BorderThickness = border_thickness,
@@ -72,7 +72,7 @@ namespace osu.Game.Modes.Taiko.UI
},
new CircularContainer
{
- Name = "Normal Ring",
+ Name = "Normal Hit Ring",
Anchor = Anchor.Centre,
Origin = Anchor.Centre,
Size = new Vector2(normal_diameter),
@@ -96,7 +96,7 @@ namespace osu.Game.Modes.Taiko.UI
Anchor = Anchor.BottomCentre,
Origin = Anchor.BottomCentre,
Y = -border_offset,
- Size = new Vector2(border_thickness, (TaikoPlayfield.PLAYFIELD_HEIGHT - finisher_diameter) / 2f - border_offset),
+ Size = new Vector2(border_thickness, (TaikoPlayfield.PLAYFIELD_HEIGHT - strong_hit_diameter) / 2f - border_offset),
Alpha = 0.1f
},
};
@@ -21,9 +21,9 @@ namespace osu.Game.Modes.Taiko.UI
private const float normal_diameter = TaikoHitObject.CIRCLE_RADIUS * 2;
///
- /// Diameter of finisher hit object circles.
+ /// Diameter of strong hit object circles.
///